# -*- coding: utf-8 -*-
from django.conf import settings
from django.db import models
from django.template.defaultfilters import slugify
from django.utils.translation import ugettext as _

from cms.models.pluginmodel import CMSPlugin
from filer.fields.image import FilerImageField

from jmb.core.db.cmsmodels import StatusModel
from jmb.core.db.models import OrderedModel, HTMLFieldTinyMCE



class AccordionSettings(CMSPlugin, StatusModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    disable_if_not_user = models.BooleanField(
        default=False,
        verbose_name=_('disable if not user (se flaggato visibile solo se loggato)'),
    )
    disable_if_not_lead = models.BooleanField(
        default=False,
        verbose_name=_('disable if not customer (se flaggato visibile solo se cliente)'),
    )
    template_name = models.CharField(
        _("Template"),
        max_length=150,
        choices=settings.ACCORDION_CMSPLUGIN_TEMPLATES,
        default="accordion/cms_plugins/accordion.html",
    )

    class Meta:
        app_label = "accordion"

    def __unicode__(self):
        return '%s %s' % (('On - ' if self.status else 'off - '), self.name)

    def get_slug(self):
        return slugify(self.name)
    get_slug.short_description = _('slug')

    # def copy_relations(self, oldinstance):
    #     for associated_item in oldinstance.associated_item.all():
    #         # instance.pk = None; instance.pk.save() is the slightly odd but
    #         # standard Django way of copying a saved model instance
    #         associated_item.pk = None
    #         associated_item.plugin = self
    #         associated_item.save()


class AccordionItemButtonSettings(OrderedModel):

    title = models.CharField(
        max_length=255,
        verbose_name=_('button title'),
    )
    url_link = models.CharField(
        max_length=255,
        verbose_name=_('link'),
        help_text="per link interni utilizzare percorsi relativi"
    )
    disable_if_not_user = models.BooleanField(
        default=False,
        verbose_name=_('disable if not user (se flaggato visibile solo se loggato)'),
    )
    disable_if_not_lead = models.BooleanField(
        default=False,
        verbose_name=_('disable if not customer (se flaggato visibile solo se cliente)'),
    )

    class Meta:
        app_label = "accordion"
        ordering = ("ordering", 'id')

    def __unicode__(self):
        return '%s' % self.title


class AccordionItemSettings(OrderedModel):
    plugin = models.ForeignKey(
        AccordionSettings,
        related_name="items"
    )
    button = models.ManyToManyField(
        AccordionItemButtonSettings,
        related_name="item_buttons", blank=True
    )
    is_collapsed = models.BooleanField(
        default=False,
        verbose_name=_('collapsed')
    )
    panel_title = models.CharField(
        max_length=255,
        verbose_name=_('panel title'),
    )
    image = FilerImageField(
        blank=True, null=True,
        verbose_name=_('image'),
        help_text='l\' immagine sarà lo sfondo dei pulsanti e deve essere 263px x 40px'
    )
    panel_body = HTMLFieldTinyMCE(
        verbose_name=_('panel body')
    )

    class Meta:
        app_label = "accordion"
        ordering = ("ordering", 'id')

    def get_slug(self):
        return slugify(self.panel_title)
    get_slug.short_description = _('slug')

    def __unicode__(self):
        return '%s: %s' % (self.plugin.name, self.panel_title)


