# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.cms.accordion.cms.models import AccordionItemSettings, AccordionSettings, AccordionItemButtonSettings


class AccordionItemButtonAdmin(admin.ModelAdmin):
    model = AccordionItemButtonSettings
    fields = ('title', 'url_link', 'disable_if_not_user', 'disable_if_not_lead',)


class AccordionItemAdmin(admin.StackedInline):
    model = AccordionItemSettings
    extra = 0
    filter_horizontal = ['button']
    fields = ('panel_title', 'is_collapsed', 'get_slug', 'ordering', 'panel_body', 'image', 'button',)
    readonly_fields = ('get_slug',)


class AccordionPlugin(CMSPluginBase):
    model = AccordionSettings
    name = _("Accordion")
    module = _("Custom CMS")
    admin_preview = False
    render_template = "accordion/cms_plugins/accordion.html"
    inlines = (AccordionItemAdmin,)

    def render(self, context, instance, placeholder):
        request = context["request"]
        self.render_template = instance.template_name
        items = instance.items.all()

        user = request.user
        link_enabled = True
        if instance.disable_if_not_lead:
            if user.is_authenticated():
                if not hasattr(user, 'profilo'):
                    link_enabled = False
                else:
                    if user.profilo.is_only_lead:
                        link_enabled = False
                    elif not user.profilo.is_lead:
                        link_enabled = False
            else:
                link_enabled = False
        elif instance.disable_if_not_user:
            if not user.is_authenticated():
                link_enabled = False

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'items': items,
            'link_enabled': link_enabled,
        })
        return context

plugin_pool.register_plugin(AccordionPlugin)
admin.site.register(AccordionItemButtonSettings, AccordionItemButtonAdmin)