# -*- coding: utf-8 -*-
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext as _

from filer.fields.image import FilerImageField

from jmb.core.db.cmsmodels import StatusModel
from cms.models.pluginmodel import CMSPlugin


class ButtonSettings(CMSPlugin, StatusModel):
    text_button = models.CharField(
        max_length=255,
        verbose_name=_('text'),
    )
    url_link = models.CharField(
        max_length=255,
        verbose_name=_('link'),
        help_text="per link interni utilizzare percorsi relativi"
    )
    target = models.CharField(
        choices=settings.BUTTON_TARGET_CHOICES,
        verbose_name=_('target'),
        max_length=2,
        default='b',
    )
    image = FilerImageField(
        blank=True, null=True,
        verbose_name=_('image'),
        help_text='l\' immagine sarà lo sfondo dei pulsanti della nav_secondary e deve essere 263px x 40px'
    )
    disable_if_not_user = models.BooleanField(
        default=False,
        verbose_name=_('disable if not user (se flaggato visibile solo se loggato)'),
    )
    disable_if_not_lead = models.BooleanField(
        default=False,
        verbose_name=_('disable if not customer (se flaggato visibile solo se cliente)'),
    )

    class Meta:
        app_label = "button"
        verbose_name = _("Button Setting")

    def __unicode__(self):
        return '%s %s' % (('On - ' if self.status else 'off - '), self.text_button)

    def get_target_value(self):
        return settings.BUTTON_TARGET_VALUES.get(self.target, self.target)