# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext as _
from cms.models.pluginmodel import CMSPlugin
from colorful.fields import RGBColorField

from jmb.core.db.cmsmodels import StatusModel
from jmb.core.db.fields import HTMLFieldTinyMCE


class CookieSettings(CMSPlugin, StatusModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    template_name = models.CharField(
        _("Template name"),
        max_length=255,
        choices=settings.COOKIE_CMSPLUGINS_COOKIE_TEMPLATES,
        default="cookie/cms_plugins/cookie.html"
    )
    body = HTMLFieldTinyMCE(
        max_length=255,
        verbose_name=_('body'),
        help_text="Use {{ policy_link }} to insert 'quì' linked text to policy page"
    )
    dismiss_text = models.CharField(
        max_length=255,
        verbose_name=_('dismiss text'),
        default="X",
    )
    policy_link = models.URLField(
        verbose_name=_("policy link"),
        max_length=255,
    )
    policy_link_name = models.CharField(
        verbose_name=_("policy link name"),
        max_length=255,
        default="qui",
    )
    text_color = RGBColorField(
        _("text color"),
    )
    background_color = RGBColorField(
        _("background color"),
    )
    background_opacity = models.FloatField(
        verbose_name=_("opacity"),
        default="1",

    )
    dismiss_on_scroll = models.BooleanField(
        _("dismiss on scroll"),
        default=True,
    )
    dismiss_on_click = models.BooleanField(
        _("dismiss on click"),
        default=True,
    )
    banner_position = models.CharField(
        verbose_name=_("Banner position"),
        max_length=255,
        choices=settings.COOKIE__BANNER_POSITION,
        default="Top"
    )

    def __unicode__(self):
        return '%s %s' % (('On - ' if self.status else 'off - '), self.name)

    class Meta:
        app_label = "cookie"
        verbose_name = _("Cookie settings")