# -*- coding: utf-8 -*-

from django.utils.translation import ugettext as _
from django.template import Context, Template
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.safestring import mark_safe
from django import forms

from jmb.cms.cookie.cms.models import CookieSettings


class CookieAdminForm(forms.ModelForm):
    background_opacity = forms.FloatField(min_value=0.0, max_value=1.0)

    class Meta:
        model = CookieSettings
        exclude = []


class CookiePlugin(CMSPluginBase):
    model = CookieSettings
    form = CookieAdminForm
    name = _("Cookie")
    module = _("Custom CMS")
    admin_preview = False
    render_template = 'cookie/cms_plugins/empty.html'

    def render(self, context, instance, placeholder):
        request = context["request"]
        if 'cookie_policy_accepted' not in request.COOKIES:
            self.render_template = instance.template_name
            template = Template(instance.body)
            context_dictionary = dict(
                policy_link=mark_safe(u"<a target='_blank' href='{0}'>{1}</a>".format(
                    instance.policy_link, instance.policy_link_name)
                )
            )
            cookie_message = template.render(Context(context_dictionary))
            context.update({
                'instance': instance,
                'placeholder': placeholder,
                'cookie_message': cookie_message,
            })
        return context


plugin_pool.register_plugin(CookiePlugin)
