# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext as _
from jmb.core.db.cmsmodels import StatusModel
from jmb.core.db.models import OrderedModel
from cms.models.pluginmodel import CMSPlugin

from imagekit.models import ProcessedImageField
from pilkit.processors import ResizeToFit
from image_cropping import ImageRatioField


class ImageGallerySettings(CMSPlugin, StatusModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('Gellery name'),
        help_text=_('Set gallery name'),
    )

    def __unicode__(self):
        return '%s %s' % (('On - ' if self.status else 'off - '), self.name)

    class Meta:
        app_label = "image_gallery"
        verbose_name = _("Gallery")


class ImageSettings(StatusModel, OrderedModel):
    gallery = models.ForeignKey(
        ImageGallerySettings,
        verbose_name=_('gallery'),
        related_name='gallery_images',
    )
    title = models.CharField(
        max_length=255,
        verbose_name=_('Title'),
        blank=True,
        null=True
    )
    original_image = ProcessedImageField(
        verbose_name=_('Original image'),
        upload_to='gallery/images',
        processors=[ResizeToFit(width=800)],
        format='JPEG',
        options={'quality': 60},
        blank=True
    )
    gallery_image = ImageRatioField(
        'original_image',
        '1200x628',
        size_warning=True
    )
    thumbnail = ImageRatioField(
        'original_image',
        '300x300',
        size_warning=True
    )
    caption = models.CharField(
        max_length=255,
        verbose_name=_('Caption'),
        blank=True,
        null=True
    )

    class Meta:
        app_label = "image_gallery"
        verbose_name = _("Gallery image")
        ordering = ['ordering']

    def __unicode__(self):
        return self.title
