# -*- coding: utf-8 -*-

from django import forms
from django.core.validators import RegexValidator
from django.core.mail import EmailMultiAlternatives
from django.template import Context
from django.template.loader import get_template
from django.utils.translation import ugettext_lazy as _

from django.conf import settings

from captcha.fields import CaptchaField


class InformationForm(forms.Form):
    nome = forms.CharField(label=_("First Name"))
    cognome = forms.CharField(label=_("Last Name"))
    email = forms.EmailField()
    telefono = forms.CharField(
        label=_("Phone"),
        error_messages={'incomplete': 'Enter a phone number.'},
        validators=[RegexValidator(r'^[0-9\-\+\/]+$', 'Enter a valid phone number.')]
    )
    privacy = forms.BooleanField(label=_("Privacy Statement"))
    captcha = CaptchaField(label=_("Parola di controllo"))

    def send(self, instance, request):
        html_template = get_template(instance.email_template_name)
        subject, from_email, to = u'Richiesta informazioni', instance.sent_from, instance.sent_to
        d = Context({
           'nome': self.cleaned_data["nome"], 'cognome': self.cleaned_data["cognome"],
           'email': self.cleaned_data["email"], 'telefono': self.cleaned_data["telefono"],
           'from_page': request.get_full_path(),
        })
        html_content = html_template.render(d)
        msg = EmailMultiAlternatives(subject, html_content, from_email, to)
        msg.content_subtype = "html"
        msg.send()

    def send_confirmation(self, instance):
        html_template = get_template(settings.INFORMATION_FORM_CMSPLUGIN_DONE_EMAIL_TEMPLATE)
        subject, from_email, to = u'Grazie per averci contattato', instance.sent_from, self.cleaned_data["email"]
        d = Context({
            'nome': self.cleaned_data["nome"], 'cognome': self.cleaned_data["cognome"],
            'email': self.cleaned_data["email"], 'telefono': self.cleaned_data["telefono"],
            'messaggio': instance.customer_done_email,
            })
        html_content = html_template.render(d)
        msg = EmailMultiAlternatives(subject, html_content, from_email, [to])
        msg.content_subtype = "html"
        msg.send()


class InformationMessageForm(forms.Form):
    nome = forms.CharField(label=_("First Name"))
    cognome = forms.CharField(label=_("Last Name"))
    email = forms.EmailField()
    telefono = forms.CharField(
        label=_("Phone"),
        error_messages={'incomplete': 'Enter a phone number.'},
        validators=[RegexValidator(r'^[0-9\-\+\/]+$', 'Enter a valid phone number.')]
    )
    messaggio = forms.CharField(
        label=_("Message"),
        widget=forms.Textarea(
            attrs={'placeholder': _("Inserisci qui il tuo messaggio"), 'cols': '80'}
        )
    )
    privacy = forms.BooleanField(label=_("Privacy Statement"))
    captcha = CaptchaField(label=_("Parola di controllo"))

    def send(self, instance, request):
        html_template = get_template(instance.email_template_name)
        subject, from_email, to = u'Richiesta informazioni', instance.sent_from, instance.sent_to
        d = Context({
           'nome': self.cleaned_data["nome"], 'cognome': self.cleaned_data["cognome"],
           'email': self.cleaned_data["email"], 'telefono': self.cleaned_data["telefono"],
           'messaggio': self.cleaned_data["messaggio"],
           'from_page': request.get_full_path(),
        })
        html_content = html_template.render(d)
        msg = EmailMultiAlternatives(subject, html_content, from_email, to)
        msg.content_subtype = "html"
        msg.send()

    def send_confirmation(self, instance):
        html_template = get_template(settings.INFORMATION_FORM_CMSPLUGIN_DONE_EMAIL_TEMPLATE)
        subject, from_email, to = u'Grazie per averci contattato', instance.sent_from, self.cleaned_data["email"]
        d = Context({
            'nome': self.cleaned_data["nome"], 'cognome': self.cleaned_data["cognome"],
            'email': self.cleaned_data["email"], 'telefono': self.cleaned_data["telefono"],
            'messaggio': instance.customer_done_email,
            })
        html_content = html_template.render(d)
        msg = EmailMultiAlternatives(subject, html_content, from_email, [to])
        msg.content_subtype = "html"
        msg.send()
