# coding: utf-8

from django.conf import settings
from django.core import validators
from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models.pluginmodel import CMSPlugin

from jmb.core.db.cmsmodels import StatusModel


class EmailListField(models.CharField):
    __metaclass__ = models.SubfieldBase

    class EmailListValidator(validators.EmailValidator):
        def __call__(self, value):
            for email in value:
                super(EmailListField.EmailListValidator, self).__call__(email)

    class Presentation(list):

        def __unicode__(self):
            return u", ".join(self)

        def __str__(self):
            return ", ".join(self)

    default_validators = [EmailListValidator()]

    def get_db_prep_value(self, value, *args, **kwargs):
        if not value:
            return
        return ','.join(unicode(s) for s in value)

    def value_to_string(self, obj):
        value = self._get_val_from_obj(obj)
        return self.get_db_prep_value(value)

    def to_python(self, value):
        if not value:
            return
        if isinstance(value, self.Presentation):
            return value
        return self.Presentation([address.strip() for address in value.split(',')])


class InformationSettings(CMSPlugin, StatusModel):
    slug = models.SlugField(
        max_length=100,
        null=True, blank=True
    )
    classes = models.CharField(
        max_length=100,
        null=True, blank=True
    )
    form = models.CharField(
        max_length=100,
        choices=settings.INFORMATION_FORM_CMSPLUGIN_FORM_CLASSES,
        default="jmb.cms.information_form.cms.forms.InformationForm",
    )
    sent_to = EmailListField(
        _('Indirizzi di destinazione delle mail'),
        max_length=250,
        help_text=_(u'Inserisci uno o più indirizzi mail separati da virgola')
    )
    sent_from = models.EmailField(
        _('Indirizzo mittente delle mail'),
    )
    privacy_statement = models.TextField(
        _('testo autorizzazione'),
        help_text=_(u"Testo autorizzazione al trattamento dei dati")
    )
    thanks = models.CharField(
        _('Messaggio di conferma'),
        max_length=250,
        help_text=_(u"Breve messaggio di testo visualizzato dall'utente una volta inviata correttamente la mail")
    )
    customer_done_email = models.TextField(
        _('Messaggio di conferma email'),
        help_text=_(u"Messaggio di testo inserito nella mail di conferma inviata all'utente")
    )
    form_template_name = models.CharField(
        max_length=100,
        choices=settings.INFORMATION_FORM_CMSPLUGIN_FORM_TEMPLATES,
        default="/cms_plugins/information_form.html"
    )
    thanks_template_name = models.CharField(
        max_length=100,
        choices=settings.INFORMATION_FORM_CMSPLUGIN_THANKS_TEMPLATES,
        default="/cms_plugins/information_thanks.html"
    )
    email_template_name = models.CharField(
        max_length=100,
        choices=settings.INFORMATION_FORM_CMSPLUGIN_EMAIL_TEMPLATES,
        default="/cms_plugins/information_email.html"
    )

    def __unicode__(self):
        return self.form_template_name

    class Meta:
        app_label = "information_form"


from south.modelsinspector import add_introspection_rules
add_introspection_rules([], ["jmb\.cms\.information_form\.cms\.models\.EmailListField"])