from django.conf import settings
from django.forms.fields import CharField
from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.core.utils.functions import import_class
from jmb.cms.information_form.cms.models import InformationSettings

from cms.plugins.text.forms import TextForm
from cms.plugins.text.widgets.wymeditor_widget import WYMEditor
from cms.plugins.text.utils import plugin_tags_to_user_html
from cms.plugins.text.settings import USE_TINYMCE


class InformationPlugin(CMSPluginBase):
    model = InformationSettings
    name = _("Information Form")
    module = _("Custom CMS")
    admin_preview = False
    render_template = "cms_plugins/empty.html"


    def get_editor_widget(self, request, plugins):
        """
        Returns the Django form Widget to be used for
        the text area
        """
        if USE_TINYMCE and "tinymce" in settings.INSTALLED_APPS:
            from cms.plugins.text.widgets.tinymce_widget import TinyMCEEditor
            return TinyMCEEditor(installed_plugins=plugins)
        else:
            return WYMEditor(installed_plugins=plugins)

    def get_form_class(self, request, plugins):
        """
        Returns a subclass of Form to be used by this plugin
        """
        # We avoid mutating the Form declared above by subclassing
        class TextPluginForm(self.form):
            pass
        widget = self.get_editor_widget(request, plugins)
        TextPluginForm.declared_fields["privacy_statement"] = CharField(widget=widget, required=False)
        return TextPluginForm

    def get_form(self, request, obj=None, **kwargs):
        plugins = plugin_pool.get_text_enabled_plugins(self.placeholder, self.page)
        form = self.get_form_class(request, plugins)
        kwargs['form'] = form # override standard form
        return super(InformationPlugin, self).get_form(request, obj, **kwargs)

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = instance.form_template_name
        form_class = import_class(instance.form)

        if request.method == "POST" and int(request.POST['plugin_id']) == instance.id:
            form = form_class(request.POST)
            if form.is_valid():
                form.send(instance, request=request)
                form.send_confirmation(instance)
                context['instance'] = instance
                form = import_class(instance.form)
                context.update({
                    'is_valid': True,
                })
        else:
            form = form_class()
        context.update({
            'information': instance,
            'form': form,
            'plugin_id': instance.id,
        })
        return context


plugin_pool.register_plugin(InformationPlugin)
