# -*- coding: utf-8 -*-
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext as _
from filer.fields.image import FilerImageField
from cms.models.pluginmodel import CMSPlugin

from jmb.core.db.cmsmodels import StatusModel
from jmb.core.db.models import OrderedModel
# from jmb.core.db.fields import HTMLFieldTinyMCE

# from adminsortable.models import Sortable
# from adminsortable.fields import SortableForeignKey

from ckeditor.fields import RichTextField as HTMLFieldTinyMCE

class MasonrySettings(CMSPlugin, StatusModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
        blank=True,
        null=True
    )

    def __unicode__(self):
        return '%s %s' % (('On - ' if self.status else 'off - '), self.name)

    class Meta:
        app_label = "masonry"
        verbose_name = _("Masonry settings")


class MasonryTaleSettings(StatusModel, OrderedModel):
    masonry = models.ForeignKey(
        MasonrySettings,
        verbose_name=_('parent'),
        related_name='tales',
    )
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
        blank=True,
        null=True
    )
    body = HTMLFieldTinyMCE(
        verbose_name=_('body'),
        blank=True,
    )
    image = FilerImageField(
        blank=True, null=True,
        verbose_name=_('image'),
    )
    mobile_image = FilerImageField(
        blank=True, null=True,
        verbose_name=_('mobile image'),
        related_name='masonry_mobile_images'
    )
    width = models.CharField(
        choices=settings.MASONRY_TALE_WIDTH_CHOICES,
        verbose_name=_('width'),
        max_length=1,
        default='1',
    )
    height = models.CharField(
        choices=settings.MASONRY_TALE_HEIGHT_CHOICES,
        verbose_name=_('height'),
        max_length=1,
        default='1',
    )
    mobile_width = models.CharField(
        choices=settings.MOBILE_MASONRY_TALE_WIDTH_CHOICES,
        verbose_name=_('mobile width'),
        max_length=1,
        default='2',
    )
    mobile_height = models.CharField(
        choices=settings.MOBILE_MASONRY_TALE_HEIGHT_CHOICES,
        verbose_name=_('mobile height'),
        max_length=1,
        default='2',
    )
    show_overlay = models.BooleanField(
        default=True
    )
    background_color = models.CharField(
        blank=True, null=True,
        max_length=7,
        verbose_name=_('tale background color HEX'),
        default='#cccccc'
    )
    foreground_color = models.CharField(
        blank=True, null=True,
        max_length=7,
        verbose_name=_('tale foreground color HEX'),
        default='#ffffff'
    )
    url_link = models.CharField(
        max_length=255,
        verbose_name=_('link'),
        help_text="per link interni utilizzare percorsi relativi"
    )
    name_link = models.CharField(
        max_length=255,
        verbose_name=_('link name'),
        blank=True,
        null=True
    )
    alt = models.CharField(
        max_length=255,
        verbose_name=_('alt'),
        blank=True,
        null=True
    )

    class Meta():
        app_label = "masonry"
        verbose_name = _("Masonry Tale Setting")
        ordering = ['ordering']

    def __unicode__(self):
        return self.name

    @property
    def masonry_class(self):
        return 'm{0}x{1}'.format(self.width, self.height)