# -*- coding: utf-8 -*-
import os
from django.db import models
from django.utils.translation import ugettext as _
from django.conf import settings
from django.template.defaultfilters import slugify

from cms.models.pluginmodel import CMSPlugin

from jmb.core.db.cmsmodels import StatusModel
from jmb.core.db.fields import HTMLFieldTinyMCE

###################################
# CMS MODELS                      #
###################################


class BSModalSettings(CMSPlugin, StatusModel):

    def get_upload_path_small(self, filename):
        raw_filename = filename
        filename = slugify(filename)
        directory = filename[0:3]
        return os.path.join(directory, raw_filename)

    slug = models.SlugField(
        verbose_name=_("Modal Slug"),
        max_length=100,
    )
    template_name = models.CharField(
        verbose_name=_("Modal Template"),
        max_length=100,
        choices=settings.MODAL_DIALOG_BOOTSTRAPMODAL_CMSPLUGIN_TEMPLATES,
        default="cms_plugins/modal_dialog.html"
    )
    modal_content_title = models.CharField(
        verbose_name=_("Modal Title"),
        max_length=100,
        null=True, blank=True,
    )
    modal_content_text = HTMLFieldTinyMCE(
        verbose_name=_("Modal Content Text"),
        null=True, blank=True,
        help_text=_("Optional scope head description"),
    )
    modal_content_image = models.ImageField(
        verbose_name=_("Modal Content Image"),
        upload_to=get_upload_path_small,
        blank=True, null=True,
    )
    modal_img_width = models.PositiveIntegerField(
        verbose_name=_("Modal Image Width Size"),
        blank=True, null=True,
    )
    modal_img_height = models.PositiveIntegerField(
        verbose_name=_("Modal Image Height Size"),
        blank=True, null=True,
    )
    modal_content_footer = HTMLFieldTinyMCE(
        verbose_name=_('Modal Footer Text'),
        null=True, blank=True,
        help_text=_("Optional scope footer text"),
    )

    class Meta(object):
        app_label = "modal_dialog"
        verbose_name = _('Bootstrap Modal Setting')
        verbose_name_plural = _('Bootstrap Modal Settings')

    # def __unicode__(self):
    #     return " - ".join("On" if self.status else "Off", self.template_name)


class ModalSettings(CMSPlugin, StatusModel):

    modal_id = models.SlugField(
        _("Modal id"),
        null=True, blank=True,
        max_length=100,
        help_text=_("(Optional) id used for modal dialog div. If omitted, it will be used "
                    "the app label and plugin instance id  ")
    )
    form = models.CharField(
        _("Modal form"),
        max_length=100,
        null=True, blank=True,
        choices=settings.MODAL_DIALOG_CMSPLUGIN_FORM_CLASSES,
        default="",
        help_text=_("(Optional) Form used inside modal dialog")
        # editable=len(settings.MODAL_DIALOG_CMSPLUGIN_FORM_CLASSES)>1
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.MODAL_DIALOG_CMSPLUGIN_TEMPLATES,
        default="modal_dialog/cms_plugins/modal_dialog.html"
    )

    def __unicode__(self):
        return " - ".join("On" if self.status else "Off", self.template_name)

    class Meta:
        app_label = "modal_dialog"


