# -*- coding: utf-8 -*-
from django.forms import ModelForm

from django.utils.translation import ugettext as _
from django.contrib import admin

from django_mptt_admin.admin import DjangoMpttAdmin

from jmb.cms.navbar.models import NavItem


class NavItemAdminForm(ModelForm):
    class Meta:
        exclude = []
        model = NavItem

    def clean(self):
        cleaned_data = super(NavItemAdminForm, self).clean()
        if self.instance.parent:
            if cleaned_data['status'] != self.instance.parent.status:
                if self.instance.parent.status == 0:
                    self.add_error(
                        'status',
                        _('Parent node is hidden, therefore this object must be hidden too')
                    )
                if self.instance.parent.status == 2 and cleaned_data['status'] == 1:
                    self.add_error(
                        'status',
                        _('Parent node is visible only to authenticated users, therefore this object cannot be Visible')
                    )
        return cleaned_data


class NavItemAdmin(DjangoMpttAdmin):
    form = NavItemAdminForm
    list_display = (
        'status', 'is_hightlighted', 'is_header', 'label', 'get_item_ancestors', 'link',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'status', ('is_hightlighted', 'is_header'), 'parent', 'label', 'link', 'html_rendered'
        )}),
    )

    def get_item_ancestors(self, obj):
        ancestors = obj.get_ancestors()
        ancestors_list = []
        for ancestor in ancestors:
            ancestors_list.append(ancestor.label)
        return " | ".join(ancestors_list)

    get_item_ancestors.short_description = _('Tree')
    get_item_ancestors.allow_tags = True

admin.site.register(NavItem, NavItemAdmin)
