# -*- coding: utf-8 -*-
from copy import deepcopy
from django.db.models import Q
from django.utils.translation import ugettext as _
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.cms.navbar.cms.models import NavSettings
from jmb.cms.navbar.generic import get_navitem_domain_link


class NavPlugin(CMSPluginBase):
    model = NavSettings
    name = _("Navbar")
    module = _("Navbar")
    admin_preview = False
    render_template = 'nav/cms_plugins/empty.html'

    def render(self, context, instance, placeholder):
        domain = get_navitem_domain_link()
        context.update({
            'url_base': domain,
        })      
        
        if not instance.status:
            return context
        
        request = context['request']
        user = request.user

        # return a TreeQuerySet of descendants of the begin node
        nodes = instance.navbar_node_begin.get_descendants().exclude(status=0)

        if not user.is_authenticated():
            nodes = nodes.exclude(status=2)

        self.render_template = instance.template_name
        actual_page_slug = self.get_actual_page_slug(request)

        context.update({
            'nodes': nodes,
            'instance': instance,
            'placeholder': placeholder,
            'actual_page_slug': actual_page_slug,
        })
        return context

    def get_actual_page_slug(self, request):
        if request.path and request.path == "/":
            return request.path
        page_slug = ""
        try:
            page_url_segments = request.path.split("/")
            page_slug = "/%s/" % "/".join([page_url_segments[i] for i in range(1,len(page_url_segments)-1)])
        except Exception:
            pass
        return page_slug

plugin_pool.register_plugin(NavPlugin)