# -*- coding: utf-8 -*-
from django.db import models
from django.template.defaultfilters import slugify
from django.utils.translation import ugettext as _

from jmb.core.db.cmsmodels import StatusModel
from jmb.core.db.models import OrderedModel

from cms.models.pluginmodel import CMSPlugin


class NavTabSettings(CMSPlugin, StatusModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )

    class Meta:
        app_label = "navtab"

    def __unicode__(self):
        return '%s %s' % (('On - ' if self.status else 'off - '), self.name)

    def get_slug(self):
        return slugify(self.name)
    get_slug.short_description = _('slug')

    def copy_relations(self, oldinstance):
        for associated_item in oldinstance.associated_item.all():
            # instance.pk = None; instance.pk.save() is the slightly odd but
            # standard Django way of copying a saved model instance
            associated_item.pk = None
            associated_item.plugin = self
            associated_item.save()


class NavTabItemSettings(OrderedModel):
    plugin = models.ForeignKey(
        NavTabSettings,
        related_name="items"
    )
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )

    class Meta:
        app_label = "navtab"
        ordering = ("ordering", 'id')

    def get_slug(self):
        return slugify(self.name)
    get_slug.short_description = _('slug')

    def __unicode__(self):
        return '%s: %s' % (self.plugin.name, self.name)
