# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext as _

from jmb.core.db.cmsmodels import StatusModel
from cms.models.pluginmodel import CMSPlugin

from imagekit.models import ProcessedImageField
from pilkit.processors import ResizeToFit
from image_cropping.fields import ImageRatioField


class ResponsiveImgSettings(CMSPlugin, StatusModel):
    name = models.CharField(
        _("image name"),
        max_length=255,
    )
    full_image = ProcessedImageField(
        verbose_name=_("Immagine full"),
        upload_to='responsive_img',
        processors=[ResizeToFit(width=1000)],
        format='JPEG',
        options={'quality': 100},
        null=True,
        blank=True
    )
    full_cropping = ImageRatioField(
        'full_image',
        free_crop=True,
        size_warning=True
    )
    mobile_image = ProcessedImageField(
        verbose_name=_("Immagine mobile"),
        upload_to='responsive_img',
        processors=[ResizeToFit(width=500)],
        format='JPEG',
        options={'quality': 100},
        null=True,
        blank=True
    )
    mobile_cropping = ImageRatioField(
        'mobile_image',
        free_crop=True,
        size_warning=True
    )
    size = models.CharField(
        _("Size"),
        choices=settings.SIZE_CHOICES,
        max_length=50,
        default='100%',
    )
    url_link = models.CharField(
        max_length=255,
        verbose_name=_('link'),
        null=True, blank=True,
        help_text="per link interni utilizzare percorsi relativi"
    )
    target = models.CharField(
        choices=settings.BUTTON_TARGET_CHOICES,
        verbose_name=_('target'),
        max_length=2,
        default='b',
    )

    class Meta:
        app_label = "responsive_img"
        verbose_name = _("responsive img Setting")

    def __unicode__(self):
        return '%s %s' % (('On - ' if self.status else 'off - '), self.name)

    def get_target_value(self):
        return settings.BUTTON_TARGET_VALUES.get(self.target, self.target)
