# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.db import models
from django.forms import forms


class IconField(models.ImageField):
    content_types = []

    def __init__(self, *args, **kwargs):
        self.content_types = settings.SHORTCUT_ICON_ALLOWED_CONTENT_TYPES
        super(IconField, self).__init__(*args, **kwargs)

    def clean(self, *args, **kwargs):

        data = super(IconField, self).clean(*args, **kwargs)
        file = data.file
        try:
            content_type = file.content_type
            if content_type in self.content_types:
                return data
            else:
                raise forms.ValidationError(_('Filetype not supported.'))
        except AttributeError:
            pass

        return data